Index: trunk/psModules/src/camera/pmFPARead.h
===================================================================
--- trunk/psModules/src/camera/pmFPARead.h	(revision 18137)
+++ trunk/psModules/src/camera/pmFPARead.h	(revision 18163)
@@ -4,6 +4,6 @@
  * @author Paul Price, IfA
  *
- * @version $Revision: 1.14 $ $Name: not supported by cvs2svn $
- * @date $Date: 2008-06-14 02:15:05 $
+ * @version $Revision: 1.15 $ $Name: not supported by cvs2svn $
+ * @date $Date: 2008-06-17 22:16:38 $
  * Copyright 2005-2006 Institute for Astronomy, University of Hawaii
  */
@@ -11,4 +11,6 @@
 #ifndef PM_FPA_READ_H
 #define PM_FPA_READ_H
+
+#include <pmConfig.h>
 
 /// @addtogroup Camera Camera Layout
@@ -20,5 +22,5 @@
                    int z,               ///< Readout number/plane; zero-offset indexing
                    int numScans,        ///< Number of scans (rows/cols) to read
-                   psDB *db             ///< Database handle for concepts
+                   pmConfig *config     ///< Configuration
     );
 
@@ -31,5 +33,5 @@
                         int numScans,   ///< Number of scans (rows/cols) to read
                         int overlap,    ///< Overlap between consecutive reads
-                        psDB *db        ///< Database handle for concepts
+                        pmConfig *config ///< Configuration
     );
 
@@ -38,5 +40,5 @@
                    psFits *fits,        ///< FITS file from which to read
                    int z,               ///< Readout number/plane; zero-offset indexing
-                   psDB *db             ///< Database handle for concepts
+                   pmConfig *config     ///< Configuration
     );
 
@@ -57,5 +59,5 @@
                        int z,           // Readout number/plane; zero-offset indexing
                        int numRows,      // The number of rows to read
-		       psDB *db
+                       pmConfig *config
                       );
 
@@ -63,5 +65,5 @@
 ///
 /// This function is type-independent (doesn't matter if you are interested in the image/mask/weight).
-int pmCellNumReadouts(pmCell *cell, psFits *fits, psDB *db);
+int pmCellNumReadouts(pmCell *cell, psFits *fits, pmConfig *config);
 
 /// Read an entire cell
@@ -71,5 +73,5 @@
 bool pmCellRead(pmCell *cell,           // Cell to read into
                 psFits *fits,           // FITS file from which to read
-                psDB *db                // Database handle, for "concepts" ingest
+                pmConfig *config        // Configuration
                );
 
@@ -79,5 +81,5 @@
 bool pmChipRead(pmChip *chip,           // Chip to read into
                 psFits *fits,           // FITS file from which to read
-                psDB *db                // Database handle, for "concepts" ingest
+                pmConfig *config        // Configuration
                );
 
@@ -87,5 +89,5 @@
 bool pmFPARead(pmFPA *fpa,              // FPA to read into
                psFits *fits,            // FITS file from which to read
-               psDB *db                 // Database handle, for "concepts" ingest
+               pmConfig *config         // Configuration
               );
 
@@ -97,5 +99,5 @@
                        int z,           ///< Readout number/plane; zero-offset indexing
                        int numScans,    ///< Number of scans (rows/cols) to read
-                       psDB *db         ///< Database handle for concepts
+                       pmConfig *config ///< Configuration
     );
 
@@ -108,5 +110,5 @@
                             int numScans, ///< Number of scans (rows/cols) to read
                             int overlap, ///< Overlap between consecutive reads
-                            psDB *db    ///< Database handle for concepts
+                            pmConfig *config ///< Configuration
     );
 
@@ -115,5 +117,5 @@
                        psFits *fits,    ///< FITS file from which to read
                        int z,           ///< Readout number/plane; zero-offset indexing
-                       psDB *db         ///< Database handle for concepts
+                       pmConfig *config ///< Configuration
     );
 
@@ -123,5 +125,5 @@
 bool pmCellReadMask(pmCell *cell,       // Cell to read into
                     psFits *fits,       // FITS file from which to read
-                    psDB *db            // Database handle, for "concepts" ingest
+                    pmConfig *config    // Configuration
                    );
 
@@ -131,5 +133,5 @@
 bool pmChipReadMask(pmChip *chip,       // Chip to read into
                     psFits *fits,       // FITS file from which to read
-                    psDB *db            // Database handle, for "concepts" ingest
+                    pmConfig *config    // Configuration
                    );
 
@@ -139,5 +141,5 @@
 bool pmFPAReadMask(pmFPA *fpa,          // FPA to read into
                    psFits *fits,        // FITS file from which to read
-                   psDB *db             // Database handle, for "concepts" ingest
+                   pmConfig *config     // Configuration
                   );
 
@@ -149,5 +151,5 @@
                          int z,         ///< Readout number/plane; zero-offset indexing
                          int numScans,  ///< Number of scans (rows/cols) to read
-                         psDB *db       ///< Database handle for concepts
+                         pmConfig *config ///< Configuration
     );
 
@@ -160,5 +162,5 @@
                               int numScans, ///< Number of scans (rows/cols) to read
                               int overlap, ///< Overlap between consecutive reads
-                              psDB *db  ///< Database handle for concepts
+                              pmConfig *config ///< Configuration
     );
 
@@ -167,5 +169,5 @@
                          psFits *fits,  ///< FITS file from which to read
                          int z,         ///< Readout number/plane; zero-offset indexing
-                         psDB *db       ///< Database handle for concepts
+                         pmConfig *config ///< Configuration
     );
 
@@ -173,7 +175,7 @@
 ///
 /// Same as pmCellRead, but reads into the weight element of the readouts.
-bool pmCellReadWeight(pmCell *cell,           // Cell to read into
-                      psFits *fits,           // FITS file from which to read
-                      psDB *db                // Database handle, for "concepts" ingest
+bool pmCellReadWeight(pmCell *cell,     // Cell to read into
+                      psFits *fits,     // FITS file from which to read
+                      pmConfig *config  // Configuration
                      );
 
@@ -181,7 +183,7 @@
 ///
 /// Same as pmChipRead, but reads into the weight element of the readouts.
-bool pmChipReadWeight(pmChip *chip,           // Chip to read into
-                      psFits *fits,           // FITS file from which to read
-                      psDB *db                // Database handle, for "concepts" ingest
+bool pmChipReadWeight(pmChip *chip,     // Chip to read into
+                      psFits *fits,     // FITS file from which to read
+                      pmConfig *config  // Configuration
                      );
 
@@ -189,7 +191,7 @@
 ///
 /// Same as pmFPARead, but reads into the weight element of the readouts.
-bool pmFPAReadWeight(pmFPA *fpa,              // FPA to read into
-                     psFits *fits,            // FITS file from which to read
-                     psDB *db                 // Database handle, for "concepts" ingest
+bool pmFPAReadWeight(pmFPA *fpa,        // FPA to read into
+                     psFits *fits,      // FITS file from which to read
+                     pmConfig *config   // Configuration
                     );
 
@@ -197,7 +199,7 @@
 ///
 /// Same as pmCellRead, but reads only the headers of the readouts.
-bool pmCellReadHeaderSet(pmCell *cell,           // Cell to read into
-                         psFits *fits,           // FITS file from which to read
-                         psDB *db                // Database handle, for "concepts" ingest
+bool pmCellReadHeaderSet(pmCell *cell,  // Cell to read into
+                         psFits *fits,  // FITS file from which to read
+                         pmConfig *config // Configuration
     );
 
@@ -205,7 +207,7 @@
 ///
 /// Same as pmChipRead, but reads only the headers of the readouts.
-bool pmChipReadHeaderSet(pmChip *chip,           // Chip to read into
-                      psFits *fits,           // FITS file from which to read
-                      psDB *db                // Database handle, for "concepts" ingest
+bool pmChipReadHeaderSet(pmChip *chip,  // Chip to read into
+                      psFits *fits,     // FITS file from which to read
+                      pmConfig *config  // Configuration
                      );
 
@@ -213,7 +215,7 @@
 ///
 /// Same as pmFPARead, but reads only the headers of the readouts.
-bool pmFPAReadHeaderSet(pmFPA *fpa,              // FPA to read into
-                        psFits *fits,            // FITS file from which to read
-                        psDB *db                 // Database handle, for "concepts" ingest
+bool pmFPAReadHeaderSet(pmFPA *fpa,     // FPA to read into
+                        psFits *fits,   // FITS file from which to read
+                        pmConfig *config // Configuration
     );
 
